import { useContext } from "react";
import { PostDetailContext } from "../context/PostDetailContext";
import { Space, Typography } from "antd";
import { PostBadge } from "../badge/PostBadge";
import {
	CalendarOutlined,
	ClockCircleOutlined,
	LockOutlined,
	UnlockOutlined,
	UserOutlined,
} from "@ant-design/icons";
import dayjs from "dayjs";
const { Title, Paragraph, Text } = Typography;
export default function Header() {
	const { post, user } = useContext(PostDetailContext);
	return (
		<header className=" rounded-t-xl bg-gradient-to-r from-primary to-primary-400 text-white p-6">
			<div className="flex flex-col space-y-6">
				{/* 主标题 */}
				<div>
					<h1 className="text-3xl font-bold tracking-wider flex items-center gap-2">
						{post?.title}

						<PostBadge type="category" value={post?.term?.name} />
						<PostBadge type="state" value={post?.state} />
					</h1>
				</div>
				<div className="space-y-4">
					{/* 收件人信息行 */}
					<Space>
						<UserOutlined className="text-white" />
						<span className="text-white">收件人：</span>

						{post?.receivers?.map((receiver, index) => (
							<Text
								strong
								className="text-white"
								key={`${index}`}>
								{receiver?.showname}
							</Text>
						))}
					</Space>

					{/* First Row - Basic Info */}
					<div className="flex flex-wrap items-center gap-1">
						{/* Author Info Badge */}
						<Space>
							<UserOutlined className="text-white" />
							<span className="text-white">发件人：</span>
							<Text className="text-white" strong>
								{post?.author?.showname || "匿名用户"}
							</Text>
						</Space>
						<Text type="secondary">|</Text>
						{/* Date Info Badge */}
						<Space>
							<CalendarOutlined className="text-white" />

							<Text className="text-white">
								创建于:
								{dayjs(post?.createdAt).format("YYYY-MM-DD")}
							</Text>
						</Space>
						<Text type="secondary">|</Text>
						{/* Last Updated Badge */}
						<Space>
							<ClockCircleOutlined className="text-white" />
							<Text className="text-white">
								更新于:
								{dayjs(post?.updatedAt).format("YYYY-MM-DD")}
							</Text>
						</Space>
						<Text type="secondary">|</Text>
						{/* Visibility Status Badge */}
						<Space>
							{post?.isPublic ? (
								<UnlockOutlined className="text-white" />
							) : (
								<LockOutlined className="text-white" />
							)}
							<Text className="text-white">
								{post?.isPublic ? "公开" : "私信"}
							</Text>
						</Space>
					</div>
					{/* Second Row - Term and Tags */}
					{post?.meta?.tags?.length > 0 && (
						<div className="flex flex-wrap gap-1">
							{/* Tags Badges */}
							{post.meta.tags.length > 0 &&
								post.meta.tags.map((tag, index) => (
									<Space key={index}>
										<PostBadge
											type="tag"
											value={`#${tag}`}></PostBadge>
									</Space>
								))}
						</div>
					)}
				</div>
			</div>
		</header>
	);
}
