import React, { useContext, useMemo } from "react";
import { Image, Button } from "antd";
import { DownloadOutlined } from "@ant-design/icons";
import { PostDetailContext } from "./context/PostDetailContext";
import { env } from "@web/src/env";
import dayjs from "dayjs";
import { PostDto } from "packages/common/dist";

export default function PostResources({ post }: { post: PostDto }) {
	const { user } = useContext(PostDetailContext);
	const resources = useMemo(() => {
		return post?.resources?.map((resource) => ({
			url: `${env.SERVER_IP}/uploads/${resource.url}`,
			title: resource.title,
		}));
	}, [post]);

	const isImage = (url: string) => {
		return /\.(png|jpg|jpeg|gif|webp)$/i.test(url);
	};

	return (
		<div className="flex flex-col gap-4">
			{resources?.map((resource) => (
				<div
					key={resource.url}
					className="flex items-center gap-4 mt-2 rounded-lg">
					{isImage(resource.url) ? (
						<>
							<Image
								src={resource.url}
								alt={resource.title}
								className="rounded-lg"
								width={"100%"}
								height={"auto"}
								style={{ objectFit: "cover" }}
							/>
						</>
					) : (
						<Button
							type="primary"
							icon={<DownloadOutlined />}
							href={resource.url}
							download
							className="bg-blue-600 hover:bg-blue-700">
							{resource.title || "下载"}
						</Button>
					)}
				</div>
			))}
		</div>
	);
}
